@@ -283,7 +283,7 @@ class TaskRequestAssembler(Assembler):
         return TaskRequest(
             task_name = UStr(dto.task_name),
             region_id = UStr(dto.region_id),
-            condition = condition_assembler.to_entity(dto.condition),
+            condition = None if dto.condition is None else condition_assembler.to_entity(dto.condition),
             git_url = None if dto.git_url is None else UStr(dto.git_url),
             git_branch = None if dto.git_branch is None else UStr(dto.git_branch),
             task_type = None if dto.task_type is None else UStr(dto.task_type),
@@ -307,7 +307,7 @@ class TaskRequestAssembler(Assembler):
         return TaskRequestDTO(
             task_name = x.task_name.get_value(),
             region_id = x.region_id.get_value(),
-            condition = condition_assembler.to_dto(x.condition),
+            condition = None if x.condition is None else condition_assembler.to_dto(x.condition),
             git_url = None if x.git_url is None else x.git_url.get_value(),
             git_branch = None if x.git_branch is None else x.git_branch.get_value(),
             task_type = None if x.task_type is None else x.task_type.get_value(),
