@@ -283,7 +283,7 @@ class TaskRequestConverter(Converter):
         return TaskRequest(
             task_name = UStr(do.task_name),
             region_id = UStr(do.region_id),
-            condition = condition_converter.to_entity(do.condition),
+            condition = None if do.condition is None else condition_converter.to_entity(do.condition),
             git_url = None if do.git_url is None else UStr(do.git_url),
             git_branch = None if do.git_branch is None else UStr(do.git_branch),
             task_type = None if do.task_type is None else UStr(do.task_type),
@@ -307,7 +307,7 @@ class TaskRequestConverter(Converter):
         return TaskRequestDO(
             task_name = x.task_name.get_value(),
             region_id = x.region_id.get_value(),
-            condition = condition_converter.to_do(x.condition),
+            condition = None if x.condition is None else condition_converter.to_do(x.condition),
             git_url = None if x.git_url is None else x.git_url.get_value(),
             git_branch = None if x.git_branch is None else x.git_branch.get_value(),
             task_type = None if x.task_type is None else x.task_type.get_value(),
